# This function plots the QTE for the alternatives considered, i.e., this code enables 
# reproduction of Figure 1 in Escanciano & Goh (2018),  ``Quantile-Regression Inference with Adaptive Control of Size''


#Inputs: dis,delta,qtile,c
dis<-1          # dis is the cdf of control group (we use dis=1,2 in the paper)
qtile<-0.25      # qtile is the quantile of interest, QTE=0 at that quantile
c<-1.5         # c is the coefficient indexing distance to the null (i.e., c=0 corresponds 
                #to the null of covariate homogeneity in the corresponding QTE); we use
                # c=0, 0.5, 1.0, 1.5 in the paper
valt<- c(1:6)  #   This indexes the specification of the parameter delta, which in turn indexes 
               #   the DGPs described in the text as Model 1, 2, 3, 4, 5 or 6 




nalt<-length(valt) 
alt<-valt[ialt] 
n<-10000
u <- runif(n)
# Generate quantiles for the error distribution 
  if (dis==1) { 
  qu <- qnorm(u)
  }
  if (dis==2) { 
  qu <- qt(u,df1)  
  }
  if (dis==3) { 
  qu <- qchisq(u, df2)-df2
  }
# delta is the normalized QTE
# Generate different alternatives 
# Generate different alternatives 
delta1 <- c*(0<=u & u<=1) # Location
delta2 <- c*(1+qu) # Location-Scale
    s1<-1
    s2<-4
    qq<-5*qbeta(u,s1,s2)
delta3 <- (qbeta(u,s1,s2)-qbeta(qtile,s1,s2)-c*qq) # 
    s1<-0.5
    s2<-0.5
delta4 <- c*2*qbeta(u,s1,s2) # 
    s1<-2
    s2<-2
delta5 <- c*2*qbeta(u,s1,s2) # 
delta6 <- (sin(2*pi*u)-sin(2*pi*qtile)-c*2*pi)/(2*pi) # sin

par(mfrow=c(2,3)) 
plot(u,delta1,xlab="u",ylab="delta",main="DGP1")
plot(u,delta2,xlab="u",ylab="delta",main="DGP2")
plot(u,delta3,xlab="u",ylab="delta",main="DGP3")
plot(u,delta4,xlab="u",ylab="delta",main="DGP4")
plot(u,delta5,xlab="u",ylab="delta",main="DGP5")
plot(u,delta6,xlab="u",ylab="delta",main="DGP6")
